@@ -21,7 +21,7 @@
 #' colWeightedSds(dm_Rle, w = 1 / rowMeans2(dm_Rle))
 setMethod("colWeightedSds", "DelayedMatrix",
           function(x, w = NULL, rows = NULL, cols = NULL, na.rm = FALSE,
-                   force_block_processing = FALSE, ...) {
+                   force_block_processing = FALSE, ..., useNames = NA) {
             sqrt(colWeightedVars(
               x = x,
               w = w,
@@ -29,6 +29,7 @@ setMethod("colWeightedSds", "DelayedMatrix",
               cols = cols,
               na.rm = na.rm,
               force_block_processing = force_block_processing,
-              ...))
+              ...,
+              useNames = useNames))
           }
 )
