@@ -6,8 +6,8 @@
 ### Exported methods
 ###
 
-.DelayedMatrix_block_rowAnyNAs <- function(x, rows, cols, ...) {
-    rowAnys(x = x, rows = rows, cols = cols, value = NA, ...)
+.DelayedMatrix_block_rowAnyNAs <- function(x, rows, cols, ..., useNames = NA) {
+    rowAnys(x = x, rows = rows, cols = cols, value = NA, ..., useNames = useNames)
 }
 
 # ------------------------------------------------------------------------------
@@ -20,12 +20,13 @@
 #' @export
 setMethod("rowAnyNAs", "DelayedMatrix",
           function(x, rows = NULL, cols = NULL, force_block_processing = FALSE,
-                   ...) {
-            .smart_seed_dispatcher(x, generic = MatrixGenerics::rowAnyNAs, 
+                   ..., useNames = NA) {
+            .smart_seed_dispatcher(x, generic = MatrixGenerics::rowAnyNAs,
                                    blockfun = .DelayedMatrix_block_rowAnyNAs,
                                    force_block_processing = force_block_processing,
                                    rows = rows,
                                    cols = cols,
-                                   ...)
+                                   ...,
+                                   useNames = useNames)
           }
 )
