@@ -19,13 +19,14 @@
 #' rowSds(dm_DF)
 setMethod("rowSds", "DelayedMatrix",
           function(x, rows = NULL, cols = NULL, na.rm = FALSE, center = NULL,
-                   force_block_processing = FALSE, ...) {
+                   force_block_processing = FALSE, ..., useNames = NA) {
             sqrt(rowVars(x = x,
                          rows = rows,
                          cols = cols,
                          na.rm = na.rm,
                          center = center,
                          force_block_processing = force_block_processing,
-                         ...))
+                         ...,
+                         useNames = useNames))
           }
 )
